==> spip_4.0.4.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'خوشامدي @nom@ !',
	'c_accueil_configurer_site' => 'پيكربندي سايت',
	'c_accueil_configurer_site_texte' => 'يكي از نخستين كارها انتخاب نام براي سايت است. 
اسم سايت در حال حاضر  «@nom@» است
اسم سايت هميشه بالاي اين صفحه نشان داده مي‌شود. 
با كليك بالا، مي‌توانيد نام سايت را اصلاح كنيد، اما همچنان يك لوگو و يك شعار به آن بدهيد. ',
	'c_accueil_publication' => 'منتشر كنيد!',
	'c_accueil_publication_texte' => 'براي انتشار يك صفحه، بايد يك مقاله ايجاد كنيد.
براي اين كار دست كم بايد يك بخش ايجاد كنيد. براي اين كار در منوي «ويرايش» روي «بخش‌ها» كليك كنيد. ',
	'c_accueil_texte' => 'وارد قسمت خصوصي اسپيپ شديد',
	'c_accueil_texte_revenir' => 'اين صفحه فعاليت‌ سردبيري اخير سايت را نشان مي‌دهد.
مي‌توانيد با كليك كردن صورتك خانه در قسمت بالاي نام خود، هر لحظه به اين صفحه بازگرديد. 

', # MODIF
	'c_article_redaction' => 'مقاله در دست نگارش است',
	'c_article_redaction_redacteur' => 'مقاله‌ي در دست ترجمه',
	'c_article_redaction_redacteur_texte' => 'براي اريه‌ي مقاله‌هاي خود به مديران و به نويسندگان ديگر، 
در داخل كادر كنار، عبارت «در دست نگارش» را به عبارت «براي انتشار» تغيير دهيد. ',
	'c_article_redaction_texte' => 'براي انتشار اين مقاله در سايت همگاني، وضعيت آن بايد تغيير كند.
در چارگوش كنار، عبارت «در دست نگارش» را به «نشر آنلاين» تغيير دهيد. ',
	'c_articles_creer' => 'چگونگي ايجاد يك مقاله؟',
	'c_articles_creer_texte' => 'نمي‌توانيد از اين صفحه يك مقاله ايجاد كنيد مگر آنكه در سايت خود دست كم يك بخش داشته باشيد.
مي‌توانيد آن را در «بخش‌ها» در زير «ويرايش» ايجاد كنيد. ',
	'c_job' => 'كارهاي آتي',
	'c_job_texte' => 'اين صفحه وظايف نگهداري آتي را كه اسپيپ بايد اجراي كند فهرست مي‌كند. اين وظايف با فواصل منظم يا موردي با توجه به رفتار‌هاي سنگين درخواست شده از سوي پلاگين‌ها، مانند ارسال انبوه ايميل، به اجرا در مي‌آيند. ',
	'c_rubrique_publier' => 'يك مقاله ايجاد كنيد',
	'c_rubrique_publier_texte' => 'يك بخش تا وقتي دست كم يك مطلب، مانند يك مقاله در آن منشر نشده باشد در سايت همگاني ديده نخواهد شد. 
پس يك مقاله ايجاد كنيد. 
اين مقاله را مي‌توانيد از اين صفحه، زير توصيف بخش خود ايجاد نماييد. ',
	'c_rubriques_creer' => 'نخستين بخش را ايجاد كنيد!',
	'c_rubriques_creer_texte' => 'بخش‌ها ساختار اساسي سايت هستند؛ شما مي‌توانيد مقاله‌ها را داخل هر يك از آن‌ها ايجاد كنيد. با ايجاد نخستين بخش شروع كنيد. ',

	// E
	'explication_activer_compagnon' => '«همراه» در بعضي از صفحه‌هاي قسمت شخصي نظراتي اضافه مي‌كند كه براي به خاطر سپردن اسپيپ كمك مي‌كنند. آيا مايليد همراه را فعال كنيد؟',
	'explication_reinitialiser_compagnon' => 'پيام‌هايي كه كس ديگري آن‌ها را قبلاً ديده ديگر نشان داده نمي‌شوند. 
آيا مايليد اين پيام‌ها ريست (بازتنظيم) شوند؟
',

	// L
	'label_activer_compagnon' => 'فعال‌سازي «همراه»؟',
	'label_reinitialiser_compagnon' => 'آيا پيام‌هاي «همراه» بازتنظيم شوند؟',

	// O
	'ok' => 'اوكي',
	'ok_bien' => 'خوبه!',
	'ok_jai_compris' => 'گرفتم!',
	'ok_merci' => 'مرسي',
	'ok_parfait' => 'كامل',

	// R
	'reinitialisation' => 'نصب مجدد',
	'reinitialisation_ok' => 'نصب مجدد انجام شدته',
	'reinitialiser' => 'بازتنظيم',
	'reinitialiser_moi' => 'بله، فقط آن‌ها كه پيشتر خوانده‌ام',
	'reinitialiser_tous' => 'بله، بي‌توجه به ديگري',

	// T
	'titre_compagnon' => 'همراه',
	'titre_page_configurer_compagnon' => 'پيكربندي «همراه».'
);

==> spip_4.4.8+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// C
	'c_accueil_bienvenue' => 'خوشامدي @nom@ !',
	'c_accueil_configurer_site' => 'پيكربندي سايت',
	'c_accueil_configurer_site_texte' => 'يكي از نخستين كارها انتخاب نام براي سايت است. 
اسم سايت در حال حاضر  «@nom@» است
اسم سايت هميشه بالاي اين صفحه نشان داده مي‌شود. 
با كليك بالا، مي‌توانيد نام سايت را اصلاح كنيد، اما همچنان يك لوگو و يك شعار به آن بدهيد. ',
	'c_accueil_publication' => 'منتشر كنيد!',
	'c_accueil_publication_texte' => 'براي انتشار يك صفحه، بايد يك مقاله ايجاد كنيد.
براي اين كار دست كم بايد يك بخش ايجاد كنيد. براي اين كار در منوي «ويرايش» روي «بخش‌ها» كليك كنيد. ',
	'c_accueil_texte' => 'وارد قسمت خصوصي اسپيپ شديد',
	'c_accueil_texte_revenir' => 'اين صفحه فعاليت‌ سردبيري اخير سايت را نشان مي‌دهد.
مي‌توانيد با كليك كردن صورتك خانه در قسمت بالاي نام خود، هر لحظه به اين صفحه بازگرديد. 

', # MODIF
	'c_article_redaction' => 'مقاله در دست نگارش است',
	'c_article_redaction_redacteur' => 'مقاله‌ي در دست ترجمه',
	'c_article_redaction_redacteur_texte' => 'براي اريه‌ي مقاله‌هاي خود به مديران و به نويسندگان ديگر، 
در داخل كادر كنار، عبارت «در دست نگارش» را به عبارت «براي انتشار» تغيير دهيد. ',
	'c_article_redaction_texte' => 'براي انتشار اين مقاله در سايت همگاني، وضعيت آن بايد تغيير كند.
در چارگوش كنار، عبارت «در دست نگارش» را به «نشر آنلاين» تغيير دهيد. ',
	'c_articles_creer' => 'چگونگي ايجاد يك مقاله؟',
	'c_articles_creer_texte' => 'نمي‌توانيد از اين صفحه يك مقاله ايجاد كنيد مگر آنكه در سايت خود دست كم يك بخش داشته باشيد.
مي‌توانيد آن را در «بخش‌ها» در زير «ويرايش» ايجاد كنيد. ',
	'c_job' => 'كارهاي آتي',
	'c_job_texte' => 'اين صفحه وظايف نگهداري آتي را كه اسپيپ بايد اجراي كند فهرست مي‌كند. اين وظايف با فواصل منظم يا موردي با توجه به رفتار‌هاي سنگين درخواست شده از سوي پلاگين‌ها، مانند ارسال انبوه ايميل، به اجرا در مي‌آيند. ',
	'c_rubrique_publier' => 'يك مقاله ايجاد كنيد',
	'c_rubrique_publier_texte' => 'يك بخش تا وقتي دست كم يك مطلب، مانند يك مقاله در آن منشر نشده باشد در سايت همگاني ديده نخواهد شد. 
پس يك مقاله ايجاد كنيد. 
اين مقاله را مي‌توانيد از اين صفحه، زير توصيف بخش خود ايجاد نماييد. ',
	'c_rubriques_creer' => 'نخستين بخش را ايجاد كنيد!',
	'c_rubriques_creer_texte' => 'بخش‌ها ساختار اساسي سايت هستند؛ شما مي‌توانيد مقاله‌ها را داخل هر يك از آن‌ها ايجاد كنيد. با ايجاد نخستين بخش شروع كنيد. ',

	// E
	'explication_activer_compagnon' => '«همراه» در بعضي از صفحه‌هاي قسمت شخصي نظراتي اضافه مي‌كند كه براي به خاطر سپردن اسپيپ كمك مي‌كنند. آيا مايليد همراه را فعال كنيد؟',
	'explication_reinitialiser_compagnon' => 'پيام‌هايي كه كس ديگري آن‌ها را قبلاً ديده ديگر نشان داده نمي‌شوند. 
آيا مايليد اين پيام‌ها ريست (بازتنظيم) شوند؟
',

	// L
	'label_activer_compagnon' => 'فعال‌سازي «همراه»؟',
	'label_reinitialiser_compagnon' => 'آيا پيام‌هاي «همراه» بازتنظيم شوند؟',

	// O
	'ok' => 'اوكي',
	'ok_bien' => 'خوبه!',
	'ok_jai_compris' => 'گرفتم!',
	'ok_merci' => 'مرسي',
	'ok_parfait' => 'كامل',

	// R
	'reinitialisation' => 'نصب مجدد',
	'reinitialisation_ok' => 'نصب مجدد انجام شدته',
	'reinitialiser' => 'بازتنظيم',
	'reinitialiser_moi' => 'بله، فقط آن‌ها كه پيشتر خوانده‌ام',
	'reinitialiser_tous' => 'بله، بي‌توجه به ديگري',

	// T
	'titre_compagnon' => 'همراه',
	'titre_page_configurer_compagnon' => 'پيكربندي «همراه».',
];
